@@ -30,7 +30,6 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <sys/stat.h>
-#include <assert.h>
 #include <fnmatch.h>
 #include <mbswidth.h>
 
@@ -221,7 +220,9 @@ const FileSetOutput &FileSetOutput::operator = (const FileSetOutput &cp)
 void FileSetOutput::config(FDStream *fd)
 {
    width = fd_width(fd->getfd());
-   assert(width != -1);
+   if(width == -1)
+      width = 80;
+
    if(!strcasecmp(ResMgr::Query("color:use-color", 0), "auto")) color = isatty(fd->getfd());
    else color = ResMgr::QueryBool("color:use-color", 0);
 }
