@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Http.cc,v 1.143 2002/01/21 16:25:15 lav Exp $ */
+/* $Id: Http.cc,v 1.144 2002/04/08 08:23:55 lav Exp $ */
 
 #include <config.h>
 #include "trio.h"
@@ -612,7 +612,7 @@ void Http::HandleHeaderLine(const char *name,const char *value)
       {
 	 if(sscanf(value,"%*[^/]/%lld",&fsize)!=1)
 	    return;
-	 if(opt_size && H_20X(status_code))
+	 if(opt_size)
 	    *opt_size=fsize;
 	 return;
       }
