@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Resolver.cc,v 1.50.2.1 2002/01/15 16:19:24 lav Exp $ */
+/* $Id: Resolver.cc,v 1.53 2002/01/21 16:25:16 lav Exp $ */
 
 #include <config.h>
 
@@ -172,11 +172,8 @@ int   Resolver::Do()
 	 int res=pipe(pipe_to_child);
 	 if(res==-1)
 	 {
-	    if(errno==ENFILE || errno==EMFILE)
-	    {
-	       TimeoutS(1);
+	    if(NonFatalError(errno))
 	       return m;
-	    }
 	    MakeErrMsg("pipe()");
 	    return MOVED;
 	 }
