@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ftpclass.cc,v 1.240 2002/03/10 10:11:44 lav Exp $ */
+/* $Id: ftpclass.cc,v 1.241 2002/03/26 12:38:56 lav Exp $ */
 
 #include <config.h>
 
@@ -1397,7 +1397,7 @@ int   Ftp::Do()
       if(mode!=CHANGE_DIR)
       {
 	 expected_response *last_cwd=FindLastCWD();
-	 if((!last_cwd && xstrcmp(cwd,real_cwd))
+	 if((!last_cwd && xstrcmp(cwd,real_cwd) && !(real_cwd==0 && !xstrcmp(cwd,"~")))
 	    || (last_cwd && xstrcmp(last_cwd->path,cwd)))
 	 {
 	    SendCWD(cwd,CHECK_CWD_CURR);
